@@ -6,7 +6,7 @@
 //  Copyright (c) 2015 Andrew Naylor. All rights reserved.
 //
 
-import StoreFoundation
+import CommerceKit
 
 /// Sequentially downloads apps, printing progress to the console.
 ///
@@ -25,15 +25,11 @@ func downloadApps(
     for appID in appIDs {
         do {
             _ = try await searcher.lookup(appID: appID)
-        } catch {
-            guard case MASError.unknownAppID = error else {
-                throw error
-            }
-
-            printWarning("App ID \(appID) not found in Mac App Store.")
+        } catch MASError.unknownAppID(let unknownAppID) {
+            printWarning("App ID", unknownAppID, "not found in Mac App Store.")
             continue
         }
-        try await downloadApp(withAppID: appID, purchasing: purchasing)
+        try await downloadApp(withAppID: appID, purchasing: purchasing, withAttemptCount: 3)
     }
 }
 
@@ -45,17 +41,13 @@ func downloadApps(
 /// - Throws: If a download fails, immediately throws an error.
 func downloadApps(withAppIDs appIDs: [AppID], purchasing: Bool = false) async throws {
     for appID in appIDs {
-        try await downloadApp(withAppID: appID, purchasing: purchasing)
+        try await downloadApp(withAppID: appID, purchasing: purchasing, withAttemptCount: 3)
     }
 }
 
-private func downloadApp(
-    withAppID appID: AppID,
-    purchasing: Bool = false,
-    withAttemptCount attemptCount: UInt32 = 3
-) async throws {
+private func downloadApp(withAppID appID: AppID, purchasing: Bool, withAttemptCount attemptCount: UInt32) async throws {
     do {
-        try await SSPurchase().perform(appID: appID, purchasing: purchasing)
+        try await downloadApp(withAppID: appID, purchasing: purchasing)
     } catch {
         guard attemptCount > 1 else {
             throw error
@@ -64,14 +56,38 @@ private func downloadApp(
         // If the download failed due to network issues, try again. Otherwise, fail immediately.
         guard
             case MASError.downloadFailed(let downloadError) = error,
-            case NSURLErrorDomain = downloadError?.domain
+            let downloadError,
+            downloadError.domain == NSURLErrorDomain
         else {
             throw error
         }
 
         let attemptCount = attemptCount - 1
-        printWarning((downloadError ?? error).localizedDescription)
-        printWarning("Trying again up to \(attemptCount) more \(attemptCount == 1 ? "time" : "times").")
+        printWarning(downloadError.localizedDescription)
+        printWarning("Retrying… ", attemptCount, " attempt", attemptCount == 1 ? "" : "s", " remaining.", separator: "")
         try await downloadApp(withAppID: appID, purchasing: purchasing, withAttemptCount: attemptCount)
     }
 }
+
+private func downloadApp(withAppID appID: AppID, purchasing: Bool = false) async throws {
+    let purchase = await SSPurchase(appID: appID, purchasing: purchasing)
+    _ = try await withCheckedThrowingContinuation { (continuation: CheckedContinuation<Void, Error>) in
+        CKPurchaseController.shared()
+            .perform(purchase, withOptions: 0) { _, _, error, response in
+                if let error {
+                    continuation.resume(throwing: MASError.purchaseFailed(error: error as NSError))
+                } else if response?.downloads.isEmpty == false {
+                    Task {
+                        do {
+                            try await PurchaseDownloadObserver(appID: appID).observeDownloadQueue()
+                            continuation.resume()
+                        } catch {
+                            continuation.resume(throwing: MASError.purchaseFailed(error: error as NSError))
+                        }
+                    }
+                } else {
+                    continuation.resume(throwing: MASError.noDownloads)
+                }
+            }
+    }
+}
