@@ -32,10 +32,11 @@ extension MAS {
                     throw MASError.noSearchResultsFound
                 }
 
-                let output = SearchResultFormatter.format(results: results, includePrice: price)
-                print(output)
+                print(SearchResultFormatter.format(results, includePrice: price))
+            } catch let error as MASError {
+                throw error
             } catch {
-                throw error as? MASError ?? .searchFailed
+                throw MASError.searchFailed
             }
         }
     }
