@@ -7,29 +7,27 @@
 //
 
 import ArgumentParser
-import StoreFoundation
 
 extension MAS {
     struct SignIn: ParsableCommand {
         static let configuration = CommandConfiguration(
             commandName: "signin",
-            abstract: "Sign in to an Apple ID in the Mac App Store"
+            abstract: "Sign in to an Apple Account in the Mac App Store"
         )
 
         @Flag(help: "Provide password via graphical dialog")
         var dialog = false
-        @Argument(help: "Apple ID")
-        var appleID: String
+        // periphery:ignore
+        @Argument(help: "Apple Account")
+        var appleAccount: String
         @Argument(help: "Password")
         var password = ""
 
         /// Runs the command.
         func run() throws {
-            do {
-                _ = try ISStoreAccount.signIn(appleID: appleID, password: password, systemDialog: dialog)
-            } catch {
-                throw error as? MASError ?? MASError.signInFailed(error: error as NSError)
-            }
+            // Signing in is no longer possible as of High Sierra.
+            // https://github.com/mas-cli/mas/issues/164
+            throw MASError.notSupported
         }
     }
 }
