@@ -24,42 +24,48 @@ extension MAS {
 
         /// Runs the command.
         func run() async throws {
-            try await run(appLibrary: await SoftwareMapAppLibrary(), searcher: ITunesSearchAppStoreSearcher())
+            try await run(installedApps: await installedApps, searcher: ITunesSearchAppStoreSearcher())
         }
 
-        func run(appLibrary: AppLibrary, searcher: AppStoreSearcher) async throws {
-            let apps = await findOutdatedApps(appLibrary: appLibrary, searcher: searcher)
+        func run(installedApps: [InstalledApp], searcher: AppStoreSearcher) async throws {
+            let apps = await findOutdatedApps(installedApps: installedApps, searcher: searcher)
 
             guard !apps.isEmpty else {
                 return
             }
 
-            print("Upgrading \(apps.count) outdated application\(apps.count > 1 ? "s" : ""):")
             print(
+                "Upgrading ",
+                apps.count,
+                " outdated application",
+                apps.count > 1 ? "s:\n" : ":\n",
                 apps.map { installedApp, storeApp in
-                    "\(storeApp.trackName) (\(installedApp.bundleVersion)) -> (\(storeApp.version))"
+                    "\(storeApp.trackName) (\(installedApp.version)) -> (\(storeApp.version))"
                 }
-                .joined(separator: "\n")
+                .joined(separator: "\n"),
+                separator: ""
             )
 
             do {
                 try await downloadApps(withAppIDs: apps.map(\.storeApp.trackId))
+            } catch let error as MASError {
+                throw error
             } catch {
-                throw error as? MASError ?? .downloadFailed(error: error as NSError)
+                throw MASError.downloadFailed(error: error as NSError)
             }
         }
 
         private func findOutdatedApps(
-            appLibrary: AppLibrary,
+            installedApps: [InstalledApp],
             searcher: AppStoreSearcher
-        ) async -> [(installedApp: SoftwareProduct, storeApp: SearchResult)] {
+        ) async -> [(installedApp: InstalledApp, storeApp: SearchResult)] {
             let apps =
                 appIDOrNames.isEmpty
-                ? appLibrary.installedApps
+                ? installedApps
                 : appIDOrNames.flatMap { appIDOrName in
                     if let appID = AppID(appIDOrName) {
                         // argument is an AppID, lookup apps by id using argument
-                        let installedApps = appLibrary.installedApps(withAppID: appID)
+                        let installedApps = installedApps.filter { $0.id == appID }
                         if installedApps.isEmpty {
                             printError(appID.unknownMessage)
                         }
@@ -67,34 +73,33 @@ extension MAS {
                     }
 
                     // argument is not an AppID, lookup apps by name using argument
-                    let installedApps = appLibrary.installedApps(named: appIDOrName)
+                    let installedApps = installedApps.filter { $0.name == appIDOrName }
                     if installedApps.isEmpty {
-                        printError("Unknown app name '\(appIDOrName)'")
+                        printError("Unknown app name '", appIDOrName, "'", separator: "")
                     }
                     return installedApps
                 }
 
-            var outdatedApps = [(SoftwareProduct, SearchResult)]()
+            var outdatedApps = [(InstalledApp, SearchResult)]()
             for installedApp in apps {
                 do {
-                    let storeApp = try await searcher.lookup(appID: installedApp.itemIdentifier.appIDValue)
+                    let storeApp = try await searcher.lookup(appID: installedApp.id)
                     if installedApp.isOutdated(comparedTo: storeApp) {
                         outdatedApps.append((installedApp, storeApp))
                     }
-                } catch {
-                    guard case MASError.unknownAppID = error else {
-                        printError(String(describing: error))
-                        continue
-                    }
-
+                } catch MASError.unknownAppID(let unknownAppID) {
                     if verbose {
                         printWarning(
-                            """
-                            Identifier \(installedApp.itemIdentifier) not found in store. \
-                            Was expected to identify \(installedApp.displayName).
-                            """
+                            "Identifier ",
+                            unknownAppID,
+                            " not found in store. Was expected to identify ",
+                            installedApp.name,
+                            ".",
+                            separator: ""
                         )
                     }
+                } catch {
+                    printError(error)
                 }
             }
             return outdatedApps
