@@ -6,8 +6,6 @@
 //  Copyright © 2024 mas-cli. All rights reserved.
 //
 
-import Foundation
-
 typealias AppID = UInt64
 
 extension AppID {
@@ -15,10 +13,3 @@ extension AppID {
         "Unknown app ID \(self)"
     }
 }
-
-// swiftlint:disable:next legacy_objc_type
-extension NSNumber {
-    var appIDValue: AppID {
-        uint64Value
-    }
-}
