@@ -12,12 +12,12 @@ import Quick
 
 @testable import mas
 
-public final class SearchResultListSpec: AsyncSpec {
+public final class SearchResultListSpec: QuickSpec {
     override public static func spec() {
         describe("search result list") {
             it("can parse bbedit") {
-                await expecta(
-                    await consequencesOf(
+                expect(
+                    consequencesOf(
                         try JSONDecoder()
                             .decode(SearchResultList.self, from: Data(from: "search/bbedit.json"))
                             .resultCount
@@ -26,8 +26,8 @@ public final class SearchResultListSpec: AsyncSpec {
                     == (1, nil, "", "")
             }
             it("can parse things") {
-                await expecta(
-                    await consequencesOf(
+                expect(
+                    consequencesOf(
                         try JSONDecoder()
                             .decode(SearchResultList.self, from: Data(from: "search/things.json"))
                             .resultCount
